@@ -41,7 +41,7 @@ class mcp_warn
 
 		if (is_array($action))
 		{
-			list($action, ) = each($action);
+			$action = key($action);
 		}
 
 		$this->page_title = 'MCP_WARN';
@@ -238,10 +238,10 @@ class mcp_warn
 
 		$user_id = $user_row['user_id'];
 
-		if (strpos($this->u_action, "&amp;f=$forum_id&amp;p=$post_id") === false)
+		if (strpos($this->u_action, "&amp;p=$post_id") === false)
 		{
-			$this->p_master->adjust_url("&amp;f=$forum_id&amp;p=$post_id");
-			$this->u_action .= "&amp;f=$forum_id&amp;p=$post_id";
+			$this->p_master->adjust_url("&amp;p=$post_id");
+			$this->u_action .= "&amp;p=$post_id";
 		}
 
 		// Check if can send a notification
@@ -358,7 +358,7 @@ class mcp_warn
 			'AVATAR_IMG'		=> $avatar_img,
 			'RANK_IMG'			=> $user_rank_data['img'],
 
-			'L_WARNING_POST_DEFAULT'	=> sprintf($user->lang['WARNING_POST_DEFAULT'], generate_board_url() . "/viewtopic.$phpEx?f=$forum_id&amp;p=$post_id#p$post_id"),
+			'L_WARNING_POST_DEFAULT'	=> sprintf($user->lang['WARNING_POST_DEFAULT'], generate_board_url() . "/viewtopic.$phpEx?p=$post_id#p$post_id"),
 
 			'S_CAN_NOTIFY'		=> $s_can_notify,
 		));
@@ -572,11 +572,12 @@ function add_warning($user_row, $warning, $send_pm = true, $post_id = 0)
 		submit_pm('post', $warn_pm_subject, $pm_data, false);
 	}
 
-	$phpbb_log->add('admin', $user->data['user_id'], $user->ip, 'LOG_USER_WARNING', false, array($user_row['username']));
-	$log_id = $phpbb_log->add('user', $user->data['user_id'], $user->ip, 'LOG_USER_WARNING_BODY', false, array(
+	$phpbb_log->add('admin', $user->data['user_id'], $user->ip, 'LOG_USER_WARNING', false, [$user_row['username']]);
+
+	$log_id = $phpbb_log->add('user', $user->data['user_id'], $user->ip, 'LOG_USER_WARNING_BODY', false, [
 		'reportee_id' => $user_row['user_id'],
-		$warning
-	));
+		utf8_encode_ucr($warning)
+	]);
 
 	$sql_ary = array(
 		'user_id'		=> $user_row['user_id'],
